@@ -8,6 +8,8 @@
 
 import torchplus
 import torch
+from torch._C import _disabled_torch_function_impl
+from collections import OrderedDict
 
 class Parameter(torchplus.Tensor):
     r"""A kind of Tensor that is to be considered a module parameter.
@@ -52,3 +54,5 @@ class Parameter(torchplus.Tensor):
             torch._utils._rebuild_parameter,
             (self.data, self.requires_grad, OrderedDict())
         )
+
+    __torch_function__ = _disabled_torch_function_impl
